import tkinter as tk
from tkinter import messagebox
import random

class GuessNumberGame:
    def __init__(self, root):
        self.root = root
        self.root.title("Guess the Number Game")
        self.root.geometry("320x260")
        self.reset_game()

        self.label = tk.Label(root, text="I'm an AI and thinking of a number\nbetween 1 and 100\nGuess It", font=("Arial", 12))
        self.label.pack(pady=10)

        self.entry = tk.Entry(root)
        self.entry.pack(pady=5)

        self.check_button = tk.Button(root, text="Check Guess", command=self.check_guess)
        self.check_button.pack(pady=5)

        self.result_label = tk.Label(root, text="", font=("Arial", 10))
        self.result_label.pack(pady=5)

    def reset_game(self):
        self.number_to_guess = random.randint(1, 100)
        self.attempts = 0

    def check_guess(self):
        try:
            guess = int(self.entry.get())
            self.attempts += 1
            difference = abs(guess - self.number_to_guess)

            if guess == self.number_to_guess:
                messagebox.showinfo("🎉 You Win!", f"Correct! You guessed it in {self.attempts} attempts.")
                play_again = messagebox.askyesno("Play Again?", "Do you want to play again?")
                if play_again:
                    self.reset_game()
                    self.entry.delete(0, tk.END)
                    self.result_label.config(text="")
                else:
                    self.root.destroy()
            elif guess < self.number_to_guess:
                if difference > 20:
                    self.result_label.config(text="Too low! ❄️")
                else:
                    self.result_label.config(text="Low.")
            elif guess > self.number_to_guess:
                if difference > 20:
                    self.result_label.config(text="Too high! 🔥")
                else:
                    self.result_label.config(text="High.")
        except ValueError:
            self.result_label.config(text="Please enter a valid number!")

# Run the GUI
if __name__ == "__main__":
    root = tk.Tk()
    game = GuessNumberGame(root)
    root.mainloop()
